@@ -63,9 +63,9 @@ _wocky_signals_marshal_BOOLEAN__OBJECT_STRING (GClosure     *closure,
                                                            gpointer     arg_1,
                                                            gpointer     arg_2,
                                                            gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -105,9 +105,9 @@ _wocky_signals_marshal_VOID__BOOLEAN_UINT_STRING (GClosure     *closure,
                                                           guint        arg_2,
                                                           gpointer     arg_3,
                                                           gpointer     data2);
-  register GMarshalFunc_VOID__BOOLEAN_UINT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__BOOLEAN_UINT_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -145,9 +145,9 @@ _wocky_signals_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                                      gpointer     arg_1,
                                                      gboolean     arg_2,
                                                      gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_BOOLEAN callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -183,9 +183,9 @@ _wocky_signals_marshal_VOID__OBJECT_ENUM_BOXED (GClosure     *closure,
                                                         gint         arg_2,
                                                         gpointer     arg_3,
                                                         gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_ENUM_BOXED callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_ENUM_BOXED callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -227,9 +227,9 @@ _wocky_signals_marshal_VOID__OBJECT_ENUM_STRING_LONG_POINTER_STRING_ENUM_BOXED (
                                                                                         gint         arg_7,
                                                                                         gpointer     arg_8,
                                                                                         gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_ENUM_STRING_LONG_POINTER_STRING_ENUM_BOXED callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_ENUM_STRING_LONG_POINTER_STRING_ENUM_BOXED callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 9);
 
@@ -276,9 +276,9 @@ _wocky_signals_marshal_VOID__OBJECT_ENUM_STRING_LONG_POINTER_STRING_STRING_ENUM
                                                                                          gpointer     arg_7,
                                                                                          gint         arg_8,
                                                                                          gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_ENUM_STRING_LONG_POINTER_STRING_STRING_ENUM callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_ENUM_STRING_LONG_POINTER_STRING_STRING_ENUM callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 9);
 
@@ -320,9 +320,9 @@ _wocky_signals_marshal_VOID__OBJECT_OBJECT_POINTER (GClosure     *closure,
                                                             gpointer     arg_2,
                                                             gpointer     arg_3,
                                                             gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_OBJECT_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_OBJECT_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -360,9 +360,9 @@ _wocky_signals_marshal_VOID__OBJECT_OBJECT_POINTER_POINTER (GClosure     *closur
                                                                     gpointer     arg_3,
                                                                     gpointer     arg_4,
                                                                     gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_OBJECT_POINTER_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_OBJECT_POINTER_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -402,9 +402,9 @@ _wocky_signals_marshal_VOID__OBJECT_OBJECT_POINTER_POINTER_BOXED (GClosure     *
                                                                           gpointer     arg_4,
                                                                           gpointer     arg_5,
                                                                           gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_OBJECT_POINTER_POINTER_BOXED callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_OBJECT_POINTER_POINTER_BOXED callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 6);
 
@@ -445,9 +445,9 @@ _wocky_signals_marshal_VOID__OBJECT_OBJECT_POINTER_POINTER_POINTER (GClosure
                                                                             gpointer     arg_4,
                                                                             gpointer     arg_5,
                                                                             gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_OBJECT_POINTER_POINTER_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_OBJECT_POINTER_POINTER_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 6);
 
@@ -486,9 +486,9 @@ _wocky_signals_marshal_VOID__OBJECT_POINTER_POINTER (GClosure     *closure,
                                                              gpointer     arg_2,
                                                              gpointer     arg_3,
                                                              gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_POINTER_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_POINTER_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -526,9 +526,9 @@ _wocky_signals_marshal_VOID__OBJECT_POINTER_POINTER_BOXED (GClosure     *closure
                                                                    gpointer     arg_3,
                                                                    gpointer     arg_4,
                                                                    gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_POINTER_POINTER_BOXED callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_POINTER_POINTER_BOXED callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -567,9 +567,9 @@ _wocky_signals_marshal_VOID__OBJECT_POINTER_POINTER_POINTER (GClosure     *closu
                                                                      gpointer     arg_3,
                                                                      gpointer     arg_4,
                                                                      gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_POINTER_POINTER_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_POINTER_POINTER_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -606,9 +606,9 @@ _wocky_signals_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                                   gpointer     arg_1,
                                                   guint        arg_2,
                                                   gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -644,9 +644,9 @@ _wocky_signals_marshal_VOID__OBJECT_UINT_POINTER (GClosure     *closure,
                                                           guint        arg_2,
                                                           gpointer     arg_3,
                                                           gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_UINT_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_UINT_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -686,9 +686,9 @@ _wocky_signals_marshal_VOID__OBJECT_UINT_POINTER_STRING_STRING_STRING (GClosure
                                                                                gpointer     arg_5,
                                                                                gpointer     arg_6,
                                                                                gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_UINT_POINTER_STRING_STRING_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_UINT_POINTER_STRING_STRING_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 7);
 
@@ -728,9 +728,9 @@ _wocky_signals_marshal_VOID__OBJECT_UINT_STRING (GClosure     *closure,
                                                          guint        arg_2,
                                                          gpointer     arg_3,
                                                          gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_UINT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_UINT_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -769,9 +769,9 @@ _wocky_signals_marshal_VOID__OBJECT_UINT_STRING_STRING_STRING (GClosure     *clo
                                                                        gpointer     arg_4,
                                                                        gpointer     arg_5,
                                                                        gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_UINT_STRING_STRING_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_UINT_STRING_STRING_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 6);
 
@@ -809,9 +809,9 @@ _wocky_signals_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                                    gpointer     arg_1,
                                                    guint        arg_2,
                                                    gpointer     data2);
-  register GMarshalFunc_VOID__POINTER_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__POINTER_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -848,9 +848,9 @@ _wocky_signals_marshal_VOID__POINTER_UINT_POINTER_POINTER (GClosure     *closure
                                                                    gpointer     arg_3,
                                                                    gpointer     arg_4,
                                                                    gpointer     data2);
-  register GMarshalFunc_VOID__POINTER_UINT_POINTER_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__POINTER_UINT_POINTER_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -887,9 +887,9 @@ _wocky_signals_marshal_VOID__STRING_UINT (GClosure     *closure,
                                                   gpointer     arg_1,
                                                   guint        arg_2,
                                                   gpointer     data2);
-  register GMarshalFunc_VOID__STRING_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -925,9 +925,9 @@ _wocky_signals_marshal_VOID__UINT_INT_STRING (GClosure     *closure,
                                                       gint         arg_2,
                                                       gpointer     arg_3,
                                                       gpointer     data2);
-  register GMarshalFunc_VOID__UINT_INT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_INT_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
